<?php

/**
 * @file
 * Contains \Drupal\pc\Logger.
 */

namespace Drupal\pc;

use Drupal\Component\Utility\SafeMarkup;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Logger\LogMessageParserInterface;
use Drupal\Core\Logger\RfcLoggerTrait;
use Drupal\Core\Session\AccountInterface;
use Psr\Log\LoggerInterface;

/**
 * Logs events in the PHP Console.
 *
 * Native PHP Console logger is not compatible with RFC 5424.
 */
class Logger implements LoggerInterface {

  use RfcLoggerTrait;

  /**
   * The message's placeholders parser.
   *
   * @var \Drupal\Core\Logger\LogMessageParserInterface
   */
  protected $parser;

  /**
   * Constructs a pc\Logger object.
   *
   * @param \Drupal\Core\Session\AccountInterface $current_user
   *   The user session.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The configuration factory object to use.
   * @param \Drupal\Core\Logger\LogMessageParserInterface $parser
   *   The parser to use when extracting message variables.
   */
  public function __construct(AccountInterface $current_user, ConfigFactoryInterface $config_factory, LogMessageParserInterface $parser) {
    $this->parser = $parser;
  }

  /**
   * {@inheritdoc}
   */
  public function log($level, $message, array $context = []) {
    $placeholders = $this->parser->parseMessagePlaceholders($message, $context);
    pc(strip_tags(SafeMarkup::format($message, $placeholders)), 'Log');
  }

}
